# template name attributes
%define templatename debian
%define templatever 10.0
%define templatearch x86_64

# Human-readable attributes
%define fullname Debian %templatever
%define fulltemplatearch (for AMD64/Intel EM64T)

# template dirs
%define templatedir /vz/template/%templatename/%templatever/%templatearch/config
%define ostemplatedir %templatedir/os/default

# vzpkgenv related
%define package_manager dpkgx64
%define package_manager_pkg vzpkgenvdebx64 >= 7.0.0

# Files lists
%define files_lst() \
find %1 -type d -printf '%%%dir %%%attr(%m,root,root) %p\\n' | sed "s,%buildroot,,g" >> %2\
find %1 -type f -printf '%%%config %%%attr(%m,root,root) %p\\n' | sed "s,%buildroot,,g" >> %2\
%nil

# Sources list
%define sources_lst() \
%((cd %_sourcedir;\
s=1;\
for tmpl in %1; do\
sources=$tmpl"_*";\
for file in $sources; do\
echo Source$s: $file;\
s=$((s+1))\
done;\
done))\
%nil

# Obsoletes list
%define obsoletes_lst() \
%((for tmpl in %1; do\
[ $tmpl = os ] && continue;\
if [ "${tmpl#os_}" != "$tmpl" ]; then\
echo "Provides: %templatename-%templatever-%templatearch-${tmpl#os_}-ez = %version-%release";\
else\
echo "Obsoletes: $tmpl-%templatename-%templatever-%templatearch-ez < 7.0.0";\
echo "Provides: $tmpl-%templatename-%templatever-%templatearch-ez = %version-%release";\
fi;
done))\
%nil

# Templates list - packages file should be always present in any template!
%define templates_list() %((cd %_sourcedir; for f in *_packages; do echo -n "${f%_*} "; done))

Summary: %fullname %fulltemplatearch Template set
Name: %templatename-%templatever-%templatearch-ez
Group: Virtuozzo/Templates
License: GPL
Version: 7.0.0
Release: 16%{?dist}
BuildRoot: %_tmppath/%name-root
BuildArch: noarch
Requires: %package_manager_pkg

# template source files
%sources_lst %templates_list

# obsoletes
%obsoletes_lst %templates_list

%description
%fullname %fulltemplatearch packaged as a Virtuozzo Template set.

%install
installfile() {
	local sourcename=%_sourcedir/${1}_$4
	local mode=$2
	local dir=$3
	local name=$4

	[ ! -f $sourcename ] && return

	install -m $mode $sourcename $dir/$name
}

rm -f files.lst
for tmpl in %templates_list; do
	if [ $tmpl = "os" ]; then
		dir=%buildroot/%ostemplatedir
		mkdir -p $dir

		# Os template only files

		# Text
		echo "%fullname %fulltemplatearch Virtuozzo Template" > $dir/description
		echo "%fullname %fulltemplatearch Virtuozzo Template" > $dir/summary

		# Package manager
		echo "%package_manager" > $dir/package_manager

		# Disable upgrade
		touch $dir/upgradable_versions

		# Pkgman environment
		installfile $tmpl 0644 $dir environment

		# vzctl-related
		installfile $tmpl 0644 $dir distribution

		# Kernel virtualization
		installfile $tmpl 0644 $dir osrelease

		# Os template cache scripts
		installfile $tmpl 0755 $dir pre-cache
		installfile $tmpl 0755 $dir post-cache
		installfile $tmpl 0755 $dir ct2vm
		installfile $tmpl 0755 $dir mid-pre-install
		installfile $tmpl 0755 $dir mid-post-install
		installfile $tmpl 0755 $dir pre-upgrade
		installfile $tmpl 0755 $dir post-upgrade

		# Additional packages
		installfile $tmpl 0644 $dir packages_0
		installfile $tmpl 0644 $dir packages_1
	elif [ "${tmpl#os_}" != "$tmpl"  ]; then
		dir=%buildroot/%templatedir/os/${tmpl#os_}
		mkdir -p $dir

		# Text
		echo "%fullname ${tmpl#os_} %fulltemplatearch Virtuozzo Template" > $dir/description
		echo "%fullname ${tmpl#os_} %fulltemplatearch Virtuozzo Template" > $dir/summary

		# Os template setname cache scripts
		installfile $tmpl 0755 $dir pre-cache
		installfile $tmpl 0755 $dir post-cache
		installfile $tmpl 0755 $dir mid-pre-install
		installfile $tmpl 0755 $dir mid-post-install
		installfile $tmpl 0755 $dir pre-upgrade
		installfile $tmpl 0755 $dir post-upgrade

		# Additional packages
		installfile $tmpl 0644 $dir packages_0
		installfile $tmpl 0644 $dir packages_1
	else
		dir=%buildroot/%templatedir/app/$tmpl/default
		mkdir -p $dir

		# App templates only files

		# Text
		echo "$tmpl for %fullname %fulltemplatearch Virtuozzo Template" > $dir/description
		echo "$tmpl for %fullname %fulltemplatearch Virtuozzo Template" > $dir/summary
	fi

	# Common things

	# Installation sources
	installfile $tmpl 0644 $dir mirrorlist
	installfile $tmpl 0644 $dir repositories

	# Packages
	installfile $tmpl 0644 $dir packages

	# Scripts
	installfile $tmpl 0755 $dir pre-install
	installfile $tmpl 0755 $dir pre-install-hn
	installfile $tmpl 0755 $dir post-install
	installfile $tmpl 0755 $dir post-install-hn

	# Versioning
	echo "%release" > $dir/release
	echo "%version" > $dir/version
	%files_lst $dir files.lst
done

%files -f files.lst

%changelog
* Mon Jan 24 2022 Denis Silakov <dsilakov@virtuozzo.com> 7.0.0-14
- Randomize timers, #PSBM-137775

* Wed Jun 30 2021 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-13
- adjust puppet repo, see #PSBM-130838

* Tue May 25 2021 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-12
- add dbus, solve #PSBM-129611

* Mon Aug 24 2020 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-10
- add puppet template
- resolve #PSBM-83653 #OVZ-7013

* Thu Oct  3 2019 Denis Silakov <dsilakov@virtuozzo.com> 7.0.0-9
- Use separate variable for debian security repos, see #PSBM-97899

* Tue Aug 13 2019 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-8
- add php-horde-idna #PSBM-96991
- add php-cli, php-pgsql to php list

* Thu Aug 8 2019 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-7
- add mariadb-server-10.3 #PSBM-96952

* Wed Aug 7 2019 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-6
- add resolvconf #PSBM-96869, bump rel
- add libtiff-dev #PSBM-96883

* Tue Aug 6 2019 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-5
- fix resolv.conf networking #PSBM-96856 #PSBM-96819

* Mon Aug 5 2019 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-4
- drop phpmyadmin template, it's dropped by the upstream
- adjust emacs-* stuff to fix #PSBM-96823
- remove pidentd
- use iptables-legacy, according to #PSBM-96822
- make symlink to point /etc/resolv.conf to systemd resolv #PSBM-96819

* Thu Jul 18 2019 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-1
- new template #PSBM-95931
